@@ -1,8 +1,20 @@
 import string
 
 import numpy as np
-import pandas.util.testing as tm
-from pandas import DataFrame, Series, MultiIndex, date_range, concat, merge, merge_asof
+
+from pandas import (
+    DataFrame,
+    Index,
+    MultiIndex,
+    Series,
+    array,
+    concat,
+    date_range,
+    merge,
+    merge_asof,
+)
+
+from .pandas_vb_common import tm
 
 try:
     from pandas import merge_ordered
@@ -10,28 +22,7 @@ except ImportError:
     from pandas import ordered_merge as merge_ordered
 
 
-class Append:
-    def setup(self):
-        self.df1 = DataFrame(np.random.randn(10000, 4), columns=["A", "B", "C", "D"])
-        self.df2 = self.df1.copy()
-        self.df2.index = np.arange(10000, 20000)
-        self.mdf1 = self.df1.copy()
-        self.mdf1["obj1"] = "bar"
-        self.mdf1["obj2"] = "bar"
-        self.mdf1["int1"] = 5
-        self.mdf1 = self.mdf1._consolidate()
-        self.mdf2 = self.mdf1.copy()
-        self.mdf2.index = self.df2.index
-
-    def time_append_homogenous(self):
-        self.df1.append(self.df2)
-
-    def time_append_mixed(self):
-        self.mdf1.append(self.mdf2)
-
-
 class Concat:
-
     params = [0, 1]
     param_names = ["axis"]
 
@@ -64,7 +55,6 @@ class Concat:
 
 
 class ConcatDataFrames:
-
     params = ([0, 1], [True, False])
     param_names = ["axis", "ignore_index"]
 
@@ -81,8 +71,53 @@ class ConcatDataFrames:
         concat(self.frame_f, axis=axis, ignore_index=ignore_index)
 
 
-class Join:
+class ConcatIndexDtype:
+    params = (
+        [
+            "datetime64[ns]",
+            "int64",
+            "Int64",
+            "int64[pyarrow]",
+            "string[python]",
+            "string[pyarrow]",
+        ],
+        ["monotonic", "non_monotonic", "has_na"],
+        [0, 1],
+        [True, False],
+    )
+    param_names = ["dtype", "structure", "axis", "sort"]
 
+    def setup(self, dtype, structure, axis, sort):
+        N = 10_000
+        if dtype == "datetime64[ns]":
+            vals = date_range("1970-01-01", periods=N)
+        elif dtype in ("int64", "Int64", "int64[pyarrow]"):
+            vals = np.arange(N, dtype=np.int64)
+        elif dtype in ("string[python]", "string[pyarrow]"):
+            vals = tm.makeStringIndex(N)
+        else:
+            raise NotImplementedError
+
+        idx = Index(vals, dtype=dtype)
+
+        if structure == "monotonic":
+            idx = idx.sort_values()
+        elif structure == "non_monotonic":
+            idx = idx[::-1]
+        elif structure == "has_na":
+            if not idx._can_hold_na:
+                raise NotImplementedError
+            idx = Index([None], dtype=dtype).append(idx)
+        else:
+            raise NotImplementedError
+
+        self.series = [Series(i, idx[:-i]) for i in range(1, 6)]
+
+    def time_concat_series(self, dtype, structure, axis, sort):
+        concat(self.series, axis=axis, sort=sort)
+
+
+class Join:
     params = [True, False]
     param_names = ["sort"]
 
@@ -130,21 +165,49 @@ class Join:
     def time_join_dataframe_index_shuffle_key_bigger_sort(self, sort):
         self.df_shuf.join(self.df_key2, on="key2", sort=sort)
 
+    def time_join_dataframes_cross(self, sort):
+        self.df.loc[:2000].join(self.df_key1, how="cross", sort=sort)
+
 
 class JoinIndex:
     def setup(self):
-        N = 50000
+        N = 5000
         self.left = DataFrame(
-            np.random.randint(1, N / 500, (N, 2)), columns=["jim", "joe"]
+            np.random.randint(1, N / 50, (N, 2)), columns=["jim", "joe"]
         )
         self.right = DataFrame(
-            np.random.randint(1, N / 500, (N, 2)), columns=["jolie", "jolia"]
+            np.random.randint(1, N / 50, (N, 2)), columns=["jolie", "jolia"]
         ).set_index("jolie")
 
     def time_left_outer_join_index(self):
         self.left.join(self.right, on="jim")
 
 
+class JoinMultiindexSubset:
+    def setup(self):
+        N = 100_000
+        mi1 = MultiIndex.from_arrays([np.arange(N)] * 4, names=["a", "b", "c", "d"])
+        mi2 = MultiIndex.from_arrays([np.arange(N)] * 2, names=["a", "b"])
+        self.left = DataFrame({"col1": 1}, index=mi1)
+        self.right = DataFrame({"col2": 2}, index=mi2)
+
+    def time_join_multiindex_subset(self):
+        self.left.join(self.right)
+
+
+class JoinEmpty:
+    def setup(self):
+        N = 100_000
+        self.df = DataFrame({"A": np.arange(N)})
+        self.df_empty = DataFrame(columns=["B", "C"], dtype="int64")
+
+    def time_inner_join_left_empty(self):
+        self.df_empty.join(self.df, how="inner")
+
+    def time_inner_join_right_empty(self):
+        self.df.join(self.df_empty, how="inner")
+
+
 class JoinNonUnique:
     # outer join of non-unique
     # GH 6329
@@ -153,7 +216,7 @@ class JoinNonUnique:
         daily_dates = date_index.to_period("D").to_timestamp("S", "S")
         self.fracofday = date_index.values - daily_dates.values
         self.fracofday = self.fracofday.astype("timedelta64[ns]")
-        self.fracofday = self.fracofday.astype(np.float64) / 86400000000000.0
+        self.fracofday = self.fracofday.astype(np.float64) / 86_400_000_000_000
         self.fracofday = Series(self.fracofday, daily_dates)
         index = date_range(date_index.min(), date_index.max(), freq="D")
         self.temp = Series(1.0, index)[self.fracofday.index]
@@ -163,7 +226,6 @@ class JoinNonUnique:
 
 
 class Merge:
-
     params = [True, False]
     param_names = ["sort"]
 
@@ -203,14 +265,53 @@ class Merge:
     def time_merge_dataframe_integer_key(self, sort):
         merge(self.df, self.df2, on="key1", sort=sort)
 
+    def time_merge_dataframe_empty_right(self, sort):
+        merge(self.left, self.right.iloc[:0], sort=sort)
+
+    def time_merge_dataframe_empty_left(self, sort):
+        merge(self.left.iloc[:0], self.right, sort=sort)
+
+    def time_merge_dataframes_cross(self, sort):
+        merge(self.left.loc[:2000], self.right.loc[:2000], how="cross", sort=sort)
+
+
+class MergeEA:
+    params = [
+        "Int64",
+        "Int32",
+        "Int16",
+        "UInt64",
+        "UInt32",
+        "UInt16",
+        "Float64",
+        "Float32",
+    ]
+    param_names = ["dtype"]
+
+    def setup(self, dtype):
+        N = 10_000
+        indices = np.arange(1, N)
+        key = np.tile(indices[:8000], 10)
+        self.left = DataFrame(
+            {"key": Series(key, dtype=dtype), "value": np.random.randn(80000)}
+        )
+        self.right = DataFrame(
+            {
+                "key": Series(indices[2000:], dtype=dtype),
+                "value2": np.random.randn(7999),
+            }
+        )
+
+    def time_merge(self, dtype):
+        merge(self.left, self.right)
+
 
 class I8Merge:
-
     params = ["inner", "outer", "left", "right"]
     param_names = ["how"]
 
     def setup(self, how):
-        low, high, n = -1000, 1000, 10 ** 6
+        low, high, n = -1000, 1000, 10**6
         self.left = DataFrame(
             np.random.randint(low, high, (n, 7)), columns=list("ABCDEFG")
         )
@@ -223,6 +324,38 @@ class I8Merge:
         merge(self.left, self.right, how=how)
 
 
+class MergeDatetime:
+    params = [
+        [
+            ("ns", "ns"),
+            ("ms", "ms"),
+            ("ns", "ms"),
+        ],
+        [None, "Europe/Brussels"],
+    ]
+    param_names = ["units", "tz"]
+
+    def setup(self, units, tz):
+        unit_left, unit_right = units
+        N = 10_000
+        keys = Series(date_range("2012-01-01", freq="T", periods=N, tz=tz))
+        self.left = DataFrame(
+            {
+                "key": keys.sample(N * 10, replace=True).dt.as_unit(unit_left),
+                "value1": np.random.randn(N * 10),
+            }
+        )
+        self.right = DataFrame(
+            {
+                "key": keys[:8000].dt.as_unit(unit_right),
+                "value2": np.random.randn(8000),
+            }
+        )
+
+    def time_merge(self, units, tz):
+        merge(self.left, self.right)
+
+
 class MergeCategoricals:
     def setup(self):
         self.left_object = DataFrame(
@@ -246,12 +379,24 @@ class MergeCategoricals:
             Z=self.right_object["Z"].astype("category")
         )
 
+        self.left_cat_col = self.left_object.astype({"X": "category"})
+        self.right_cat_col = self.right_object.astype({"X": "category"})
+
+        self.left_cat_idx = self.left_cat_col.set_index("X")
+        self.right_cat_idx = self.right_cat_col.set_index("X")
+
     def time_merge_object(self):
         merge(self.left_object, self.right_object, on="X")
 
     def time_merge_cat(self):
         merge(self.left_cat, self.right_cat, on="X")
 
+    def time_merge_on_cat_col(self):
+        merge(self.left_cat_col, self.right_cat_col, on="X")
+
+    def time_merge_on_cat_idx(self):
+        merge(self.left_cat_idx, self.right_cat_idx, on="X")
+
 
 class MergeOrdered:
     def setup(self):
@@ -272,10 +417,10 @@ class MergeOrdered:
 
 
 class MergeAsof:
-    params = [["backward", "forward", "nearest"]]
-    param_names = ["direction"]
+    params = [["backward", "forward", "nearest"], [None, 5]]
+    param_names = ["direction", "tolerance"]
 
-    def setup(self, direction):
+    def setup(self, direction, tolerance):
         one_count = 200000
         two_count = 1000000
 
@@ -302,6 +447,9 @@ class MergeAsof:
         df1["time32"] = np.int32(df1.time)
         df2["time32"] = np.int32(df2.time)
 
+        df1["timeu64"] = np.uint64(df1.time)
+        df2["timeu64"] = np.uint64(df2.time)
+
         self.df1a = df1[["time", "value1"]]
         self.df2a = df2[["time", "value2"]]
         self.df1b = df1[["time", "key", "value1"]]
@@ -312,29 +460,95 @@ class MergeAsof:
         self.df2d = df2[["time32", "value2"]]
         self.df1e = df1[["time", "key", "key2", "value1"]]
         self.df2e = df2[["time", "key", "key2", "value2"]]
+        self.df1f = df1[["timeu64", "value1"]]
+        self.df2f = df2[["timeu64", "value2"]]
 
-    def time_on_int(self, direction):
-        merge_asof(self.df1a, self.df2a, on="time", direction=direction)
-
-    def time_on_int32(self, direction):
-        merge_asof(self.df1d, self.df2d, on="time32", direction=direction)
-
-    def time_by_object(self, direction):
-        merge_asof(self.df1b, self.df2b, on="time", by="key", direction=direction)
-
-    def time_by_int(self, direction):
-        merge_asof(self.df1c, self.df2c, on="time", by="key2", direction=direction)
-
-    def time_multiby(self, direction):
+    def time_on_int(self, direction, tolerance):
         merge_asof(
-            self.df1e, self.df2e, on="time", by=["key", "key2"], direction=direction
+            self.df1a, self.df2a, on="time", direction=direction, tolerance=tolerance
         )
 
+    def time_on_int32(self, direction, tolerance):
+        merge_asof(
+            self.df1d, self.df2d, on="time32", direction=direction, tolerance=tolerance
+        )
+
+    def time_on_uint64(self, direction, tolerance):
+        merge_asof(
+            self.df1f, self.df2f, on="timeu64", direction=direction, tolerance=tolerance
+        )
+
+    def time_by_object(self, direction, tolerance):
+        merge_asof(
+            self.df1b,
+            self.df2b,
+            on="time",
+            by="key",
+            direction=direction,
+            tolerance=tolerance,
+        )
+
+    def time_by_int(self, direction, tolerance):
+        merge_asof(
+            self.df1c,
+            self.df2c,
+            on="time",
+            by="key2",
+            direction=direction,
+            tolerance=tolerance,
+        )
+
+    def time_multiby(self, direction, tolerance):
+        merge_asof(
+            self.df1e,
+            self.df2e,
+            on="time",
+            by=["key", "key2"],
+            direction=direction,
+            tolerance=tolerance,
+        )
+
+
+class MergeMultiIndex:
+    params = [
+        [
+            ("int64", "int64"),
+            ("datetime64[ns]", "int64"),
+            ("Int64", "Int64"),
+        ],
+        ["left", "right", "inner", "outer"],
+    ]
+    param_names = ["dtypes", "how"]
+
+    def setup(self, dtypes, how):
+        n = 100_000
+        offset = 50_000
+        mi1 = MultiIndex.from_arrays(
+            [
+                array(np.arange(n), dtype=dtypes[0]),
+                array(np.arange(n), dtype=dtypes[1]),
+            ]
+        )
+        mi2 = MultiIndex.from_arrays(
+            [
+                array(np.arange(offset, n + offset), dtype=dtypes[0]),
+                array(np.arange(offset, n + offset), dtype=dtypes[1]),
+            ]
+        )
+        self.df1 = DataFrame({"col1": 1}, index=mi1)
+        self.df2 = DataFrame({"col2": 2}, index=mi2)
+
+    def time_merge_sorted_multiindex(self, dtypes, how):
+        # copy to avoid MultiIndex._values caching
+        df1 = self.df1.copy()
+        df2 = self.df2.copy()
+        merge(df1, df2, how=how, left_index=True, right_index=True)
+
 
 class Align:
     def setup(self):
-        size = 5 * 10 ** 5
-        rng = np.arange(0, 10 ** 13, 10 ** 7)
+        size = 5 * 10**5
+        rng = np.arange(0, 10**13, 10**7)
         stamps = np.datetime64("now").view("i8") + rng
         idx1 = np.sort(np.random.choice(stamps, size, replace=False))
         idx2 = np.sort(np.random.choice(stamps, size, replace=False))
@@ -348,4 +562,4 @@ class Align:
         self.ts1.align(self.ts2, join="left")
 
 
-from .pandas_vb_common import setup  # noqa: F401
+from .pandas_vb_common import setup  # noqa: F401 isort:skip
