@@ -87,7 +87,9 @@ class TestMultiIndexSetItem:
             [["foo", "bar"], date_range("2016-01-01", "2016-02-01", freq="MS")]
         )
 
-        df = DataFrame(np.random.random((12, 4)), index=idx, columns=cols)
+        df = DataFrame(
+            np.random.default_rng(2).random((12, 4)), index=idx, columns=cols
+        )
 
         subidx = MultiIndex.from_tuples(
             [("A", Timestamp("2015-01-01")), ("A", Timestamp("2015-02-01"))]
@@ -96,7 +98,9 @@ class TestMultiIndexSetItem:
             [("foo", Timestamp("2016-01-01")), ("foo", Timestamp("2016-02-01"))]
         )
 
-        vals = DataFrame(np.random.random((2, 2)), index=subidx, columns=subcols)
+        vals = DataFrame(
+            np.random.default_rng(2).random((2, 2)), index=subidx, columns=subcols
+        )
         self.check(
             target=df,
             indexers=(subidx, subcols),
@@ -104,7 +108,9 @@ class TestMultiIndexSetItem:
             compare_fn=tm.assert_frame_equal,
         )
         # set all columns
-        vals = DataFrame(np.random.random((2, 4)), index=subidx, columns=cols)
+        vals = DataFrame(
+            np.random.default_rng(2).random((2, 4)), index=subidx, columns=cols
+        )
         self.check(
             target=df,
             indexers=(subidx, slice(None, None, None)),
@@ -134,7 +140,9 @@ class TestMultiIndexSetItem:
         ]
 
         df_orig = DataFrame(
-            np.random.randn(6, 3), index=arrays, columns=["A", "B", "C"]
+            np.random.default_rng(2).standard_normal((6, 3)),
+            index=arrays,
+            columns=["A", "B", "C"],
         ).sort_index()
 
         expected = df_orig.loc[["bar"]] * 2
@@ -183,7 +191,7 @@ class TestMultiIndexSetItem:
 
         # mixed dtype
         df = DataFrame(
-            np.random.randint(5, 10, size=9).reshape(3, 3),
+            np.random.default_rng(2).integers(5, 10, size=9).reshape(3, 3),
             columns=list("abc"),
             index=[[4, 4, 8], [8, 10, 12]],
         )
@@ -199,7 +207,7 @@ class TestMultiIndexSetItem:
         arr = np.array([0.0, 1.0])
 
         df = DataFrame(
-            np.random.randint(5, 10, size=9).reshape(3, 3),
+            np.random.default_rng(2).integers(5, 10, size=9).reshape(3, 3),
             columns=list("abc"),
             index=[[4, 4, 8], [8, 10, 12]],
             dtype=np.int64,
@@ -217,7 +225,10 @@ class TestMultiIndexSetItem:
             tm.assert_numpy_array_equal(view, exp.values)
 
         # arr + 0.5 cannot be cast losslessly to int, so we upcast
-        df.loc[4, "c"] = arr + 0.5
+        with tm.assert_produces_warning(
+            FutureWarning, match="item of incompatible dtype"
+        ):
+            df.loc[4, "c"] = arr + 0.5
         result = df.loc[4, "c"]
         exp = exp + 0.5
         tm.assert_series_equal(result, exp)
@@ -248,7 +259,7 @@ class TestMultiIndexSetItem:
         index_cols = col_names[:5]
 
         df = DataFrame(
-            np.random.randint(5, size=(NUM_ROWS, NUM_COLS)),
+            np.random.default_rng(2).integers(5, size=(NUM_ROWS, NUM_COLS)),
             dtype=np.int64,
             columns=col_names,
         )
@@ -328,7 +339,8 @@ class TestMultiIndexSetItem:
 
     def test_frame_setitem_multi_column(self):
         df = DataFrame(
-            np.random.randn(10, 4), columns=[["a", "a", "b", "b"], [0, 1, 0, 1]]
+            np.random.default_rng(2).standard_normal((10, 4)),
+            columns=[["a", "a", "b", "b"], [0, 1, 0, 1]],
         )
 
         cp = df.copy()
@@ -380,7 +392,9 @@ class TestMultiIndexSetItem:
         )
 
         obj = DataFrame(
-            np.random.randn(len(index), 4), index=index, columns=["a", "b", "c", "d"]
+            np.random.default_rng(2).standard_normal((len(index), 4)),
+            index=index,
+            columns=["a", "b", "c", "d"],
         )
         obj = tm.get_obj(obj, frame_or_series)
 
@@ -463,7 +477,7 @@ class TestSetitemWithExpansionMultiIndex:
 
         tuples = sorted(zip(*arrays))
         index = MultiIndex.from_tuples(tuples)
-        df = DataFrame(np.random.randn(4, 6), columns=index)
+        df = DataFrame(np.random.default_rng(2).standard_normal((4, 6)), columns=index)
 
         result = df.copy()
         expected = df.copy()
@@ -542,3 +556,21 @@ def test_frame_setitem_copy_no_write(
 
     result = df
     tm.assert_frame_equal(result, expected)
+
+
+def test_frame_setitem_partial_multiindex():
+    # GH 54875
+    df = DataFrame(
+        {
+            "a": [1, 2, 3],
+            "b": [3, 4, 5],
+            "c": 6,
+            "d": 7,
+        }
+    ).set_index(["a", "b", "c"])
+    ser = Series(8, index=df.index.droplevel("c"))
+    result = df.copy()
+    result["d"] = ser
+    expected = df.copy()
+    expected["d"] = 8
+    tm.assert_frame_equal(result, expected)
