@@ -5,6 +5,7 @@ from datetime import (
     timedelta,
     timezone,
 )
+import zoneinfo
 
 import dateutil.tz
 from dateutil.tz import tzutc
@@ -13,23 +14,30 @@ import pytest
 import pytz
 
 from pandas._libs.tslibs.dtypes import NpyDatetimeUnit
-from pandas.compat import (
-    PY39,
-    PY310,
-)
+from pandas.compat import PY310
 from pandas.errors import OutOfBoundsDatetime
 
 from pandas import (
+    NA,
+    NaT,
     Period,
     Timedelta,
     Timestamp,
 )
 
-if PY39:
-    import zoneinfo
-
 
 class TestTimestampConstructors:
+    def test_construct_from_time_unit(self):
+        # GH#54097 only passing a time component, no date
+        ts = Timestamp("01:01:01.111")
+        assert ts.unit == "ms"
+
+    def test_weekday_but_no_day_raises(self):
+        # GH#52659
+        msg = "Parsing datetimes with weekday but no day information is not supported"
+        with pytest.raises(ValueError, match=msg):
+            Timestamp("2023 Sept Thu")
+
     def test_construct_from_string_invalid_raises(self):
         # dateutil (weirdly) parses "200622-12-31" as
         #  datetime(2022, 6, 20, 12, 0, tzinfo=tzoffset(None, -111600)
@@ -58,6 +66,12 @@ class TestTimestampConstructors:
         ts = Timestamp("2016 June 3 15:25:01.345")
         assert ts.unit == "ms"
 
+        ts = Timestamp("300-01-01")
+        assert ts.unit == "s"
+
+        ts = Timestamp("300 June 1:30:01.300")
+        assert ts.unit == "ms"
+
     def test_constructor_from_iso8601_str_with_offset_reso(self):
         # GH#49737
         ts = Timestamp("2016-01-01 04:05:06-01:00")
@@ -716,7 +730,7 @@ class TestTimestampConstructors:
         assert isinstance(result, Timestamp)
 
 
-def test_constructor_ambigous_dst():
+def test_constructor_ambiguous_dst():
     # GH 24329
     # Make sure that calling Timestamp constructor
     # on Timestamp created from ambiguous time
@@ -839,12 +853,13 @@ def test_timestamp_constructor_retain_fold(tz, fold):
     assert result == expected
 
 
-_tzs = ["dateutil/Europe/London"]
-if PY39:
-    try:
-        _tzs = ["dateutil/Europe/London", zoneinfo.ZoneInfo("Europe/London")]
-    except zoneinfo.ZoneInfoNotFoundError:
-        pass
+try:
+    _tzs = [
+        "dateutil/Europe/London",
+        zoneinfo.ZoneInfo("Europe/London"),
+    ]
+except zoneinfo.ZoneInfoNotFoundError:
+    _tzs = ["dateutil/Europe/London"]
 
 
 @pytest.mark.parametrize("tz", _tzs)
@@ -885,3 +900,11 @@ def test_timestamp_constructor_adjust_value_for_fold(tz, ts_input, fold, value_o
     result = ts._value
     expected = value_out
     assert result == expected
+
+
+@pytest.mark.parametrize("na_value", [None, np.nan, np.datetime64("NaT"), NaT, NA])
+def test_timestamp_constructor_na_value(na_value):
+    # GH45481
+    result = Timestamp(na_value)
+    expected = NaT
+    assert result is expected
